qepcad: Quantifier elimination by partial cylindrical algebraic decomposition
=============================================================================

Description
-----------

Qepcad is an implementation of quantifier elimination by partial
cylindrical algebraic decomposition

License
-------

ICS :wikipedia:`ISC_license`

Upstream Contact
----------------

- Repository:  https://github.com/chriswestbrown/qepcad
- Tarballs:   https://www.usna.edu/Users/cs/wcbrown/qepcad/INSTALL/IQ.html
- Website: (outdated) https://www.usna.edu/Users/cs/wcbrown/qepcad/B/QEPCAD.html
